@@ -26,6 +26,9 @@
 #include <polkit-dbus/polkit-dbus.h>
 #include <QDebug>
 
+#include <sys/types.h>
+#include <unistd.h>
+
 using namespace PolkitQt;
 
 class Action::Private
