@@ -32,58 +32,69 @@
 #include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusConnection>
 #include <QtCore/QDebug>
+#include <QtDBus/qdbuspendingcall.h>
 
 using namespace PolkitQt;
 
-bool Auth::computeAndObtainAuth(const QString &actionId, uint winId, uint pid)
+namespace PolkitQt {
+namespace Auth {
+
+    Result polkitResultToResult(PolKitResult res);
+}
+}
+
+bool Auth::computeAndObtainAuth(const QString &actionId, WId winId, qint64 pid)
 {
     PolKitAction *pkAction = polkit_action_new();
     if (!polkit_action_set_action_id(pkAction, actionId.toAscii().data())) {
         return false;
     }
-    PolKitResult result;
+    Result result;
     // set revokeIfOneShot to false as we only want to check it,
     // otherwise we would be revoking one shot actions
     result = isCallerAuthorized(pkAction, pid, false);
     switch (result) {
-    case POLKIT_RESULT_YES:
+    case Yes:
         // If PolicyKit says yes.. emit the 'activated' signal
         return true;
         break;
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_ONE_SHOT:
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH:
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_KEEP_SESSION:
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_KEEP_ALWAYS:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_ONE_SHOT:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_KEEP_SESSION:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_KEEP_ALWAYS:
+    case AdminAuthOneShot:
+    case AdminAuth:
+    case AdminAuthKeepAlways:
+    case AdminAuthKeepSession:
+    case SelfAuthOneShot:
+    case SelfAuth:
+    case SelfAuthKeepAlways:
+    case SelfAuthKeepSession:
         // Otherwise, the action needs auth..
         // we now issue the obtain auth dialog
         if (pkAction != 0) {
             return obtainAuth(actionId, winId, pid);
         }
     default:
-    case POLKIT_RESULT_NO:
+    case No:
         // if result is no then the user cannot even try to auth
         return false;
         break;
     }
 }
 
-bool Auth::obtainAuth(const QString &actionId, uint winId, uint pid)
+bool Auth::obtainAuth(const QString &actionId, WId winId, qint64 pid)
 {
     QDBusMessage message;
     message = QDBusMessage::createMethodCall(PK_NAME,
-                                             PK_PATH,
-                                             PK_INTERFACE,
-                                             QLatin1String("ObtainAuthorization"));
+              PK_PATH,
+              PK_INTERFACE,
+              QLatin1String("ObtainAuthorization"));
     QList<QVariant> argumentList;
-    argumentList << qVariantFromValue(actionId) << qVariantFromValue(winId) << qVariantFromValue(pid);
+    argumentList << qVariantFromValue(actionId) << qVariantFromValue(uint(winId)) << qVariantFromValue(uint(pid));
     message.setArguments(argumentList);
-    // Do a session bus call with BlockWithGui to create an event loop
-    // and INT_MAX to get the highier timeout
-    QDBusMessage reply = QDBusConnection::sessionBus().call(message, QDBus::BlockWithGui, INT_MAX);
+    QEventLoop e;
+    QDBusPendingCall pcall = QDBusConnection::sessionBus().asyncCall(message);
+    QDBusPendingCallWatcher watcher(pcall);
+    e.connect(&watcher, SIGNAL(finished(QDBusPendingCallWatcher*)), &e, SLOT(quit()));
+    e.exec();
+    QDBusMessage reply = pcall.reply();
     if (reply.type() == QDBusMessage::ReplyMessage && reply.arguments().size() == 1) {
         return reply.arguments().first().toBool();
     } else if (reply.type() == QDBusMessage::MethodCallMessage) {
@@ -92,51 +103,51 @@ bool Auth::obtainAuth(const QString &actionId, uint winId, uint pid)
     return false;
 }
 
-PolKitResult Auth::isCallerAuthorized(const QString &actionId, uint pid, bool revokeIfOneShot)
+Auth::Result Auth::isCallerAuthorized(const QString &actionId, qint64 pid, bool revokeIfOneShot)
 {
     PolKitAction *pk_action = polkit_action_new();
 
     if (!polkit_action_set_action_id(pk_action, actionId.toAscii().data())) {
-        return POLKIT_RESULT_UNKNOWN;
+        return Unknown;
     }
 
     return isCallerAuthorized(pk_action, pid, revokeIfOneShot);
 }
 
-PolKitResult Auth::isCallerAuthorized(PolKitAction *action, pid_t pid, bool revokeIfOneShot)
+Auth::Result Auth::isCallerAuthorized(PolKitAction *action, qint64 pid, bool revokeIfOneShot)
 {
     PolKitCaller *pk_caller;
     PolKitResult pk_result;
     DBusError dbus_error;
 
     if (Context::instance()->hasError()) {
-        return pk_result = POLKIT_RESULT_UNKNOWN;
+        return Unknown;
     }
 
-    dbus_error_init (&dbus_error);
+    dbus_error_init(&dbus_error);
     pk_caller = polkit_tracker_get_caller_from_pid(Context::instance()->getPolKitTracker(),
-                                                   pid,
-                                                   &dbus_error);
+                pid,
+                &dbus_error);
     if (pk_caller == NULL) {
-        qWarning("Cannot get PolKitCaller object for target (pid=%d): %s: %s",
+        qWarning("Cannot get PolKitCaller object for target (pid=%lld): %s: %s",
                  pid, dbus_error.name, dbus_error.message);
         dbus_error_free(&dbus_error);
 
         // this is bad so cop-out to UKNOWN
         pk_result = POLKIT_RESULT_UNKNOWN;
     } else {
-        pk_result = polkit_context_is_caller_authorized (Context::instance()->getPolKitContext(),
-                                                        action,
-                                                        pk_caller,
-                                                        revokeIfOneShot,
-                                                        NULL);
-        polkit_caller_unref (pk_caller);
+        pk_result = polkit_context_is_caller_authorized(Context::instance()->getPolKitContext(),
+                    action,
+                    pk_caller,
+                    revokeIfOneShot,
+                    NULL);
+        polkit_caller_unref(pk_caller);
     }
 
-    return pk_result;
+    return polkitResultToResult(pk_result);
 }
 
-PolKitResult Auth::isCallerAuthorized(PolKitAction *action,
+Auth::Result Auth::isCallerAuthorized(PolKitAction *action,
                                       const QString &dbusName,
                                       bool revokeIfOneShot)
 {
@@ -145,41 +156,79 @@ PolKitResult Auth::isCallerAuthorized(PolKitAction *action,
     DBusError dbus_error;
 
     if (Context::instance()->hasError()) {
-        return pk_result = POLKIT_RESULT_UNKNOWN;
+        return Unknown;
     }
 
-    dbus_error_init (&dbus_error);
+    dbus_error_init(&dbus_error);
     pk_caller = polkit_tracker_get_caller_from_dbus_name(Context::instance()->getPolKitTracker(),
-                                                         dbusName.toLatin1().data(),
-                                                         &dbus_error);
+                dbusName.toLatin1().data(),
+                &dbus_error);
     if (pk_caller == NULL) {
-        qWarning("Cannot get PolKitCaller object for DBus name (dbusName=%d): %s: %s",
+        qWarning("Cannot get PolKitCaller object for DBus name (dbusName=%s): %s: %s",
                  qPrintable(dbusName), dbus_error.name, dbus_error.message);
         dbus_error_free(&dbus_error);
 
         // this is bad so cop-out to UKNOWN
         pk_result = POLKIT_RESULT_UNKNOWN;
     } else {
-        pk_result = polkit_context_is_caller_authorized (Context::instance()->getPolKitContext(),
-                                                        action,
-                                                        pk_caller,
-                                                        revokeIfOneShot,
-                                                        NULL);
-        polkit_caller_unref (pk_caller);
+        pk_result = polkit_context_is_caller_authorized(Context::instance()->getPolKitContext(),
+                    action,
+                    pk_caller,
+                    revokeIfOneShot,
+                    NULL);
+        polkit_caller_unref(pk_caller);
     }
 
-    return pk_result;
+    return polkitResultToResult(pk_result);
 }
 
-PolKitResult Auth::isCallerAuthorized(const QString &actionId,
+Auth::Result Auth::isCallerAuthorized(const QString &actionId,
                                       const QString &dbusName,
                                       bool revokeIfOneShot)
 {
     PolKitAction *pk_action = polkit_action_new();
 
     if (!polkit_action_set_action_id(pk_action, actionId.toAscii().data())) {
-        return POLKIT_RESULT_UNKNOWN;
+        return Unknown;
     }
 
     return isCallerAuthorized(pk_action, dbusName, revokeIfOneShot);
 }
+
+Auth::Result Auth::polkitResultToResult(PolKitResult result) {
+    switch (result) {
+        case POLKIT_RESULT_YES:
+            return Auth::Yes;
+            break;
+        case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_ONE_SHOT:
+            return Auth::AdminAuthOneShot;
+            break;
+        case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH:
+            return Auth::AdminAuth;
+            break;
+        case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_KEEP_SESSION:
+            return Auth::AdminAuthKeepSession;
+            break;
+        case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_KEEP_ALWAYS:
+            return Auth::AdminAuthKeepAlways;
+            break;
+        case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_ONE_SHOT:
+            return Auth::SelfAuthOneShot;
+            break;
+        case POLKIT_RESULT_ONLY_VIA_SELF_AUTH:
+            return Auth::SelfAuth;
+            break;
+        case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_KEEP_SESSION:
+            return Auth::SelfAuthKeepSession;
+            break;
+        case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_KEEP_ALWAYS:
+            return Auth::SelfAuthKeepAlways;
+            break;
+        case POLKIT_RESULT_NO:
+            return Auth::No;
+            break;
+        default:
+            return Auth::Unknown;
+            break;
+    }
+}
