@@ -1,3 +1,4 @@
+// This is an example not a library
 /***************************************************************************
  *   Copyright (C) 2008 Daniel Nicoletti <dantti85-pk@yahoo.com.br>        *
  *                                                                         *
@@ -53,7 +54,7 @@ PkExample::PkExample(QMainWindow *parent)
     // This signal was propagated from the QAbstractButton just for
     // convenience in this case we don't have any benefit but the code
     // look cleaner
-    connect(bt, SIGNAL(clicked(QAbstractButton*,bool)), bt, SLOT(activate()));
+    connect(bt, SIGNAL(clicked(QAbstractButton*, bool)), bt, SLOT(activate()));
     // this is the Action activated signal, it is always emmited whenever
     // someone click and get authorized to do the action
     connect(bt, SIGNAL(activated()), this, SLOT(actionActivated()));
@@ -64,7 +65,7 @@ PkExample::PkExample(QMainWindow *parent)
     menuActions->addAction(qobject_cast<Action*>(bt));
     toolBar->addAction(qobject_cast<Action*>(bt));
     connect(bt, SIGNAL(triggered(bool)), this, SLOT(activateAction()));
-    connect(bt, SIGNAL(clicked(QAbstractButton*,bool)), bt, SLOT(activate()));
+    connect(bt, SIGNAL(clicked(QAbstractButton*, bool)), bt, SLOT(activate()));
     connect(bt, SIGNAL(activated()), this, SLOT(actionActivated()));
 
     // This action is more customized
@@ -92,7 +93,7 @@ PkExample::PkExample(QMainWindow *parent)
     menuActions->addAction(qobject_cast<Action*>(bt));
     toolBar->addAction(qobject_cast<Action*>(bt));
     connect(bt, SIGNAL(triggered(bool)), this, SLOT(activateAction()));
-    connect(bt, SIGNAL(clicked(QAbstractButton*,bool)), bt, SLOT(activate()));
+    connect(bt, SIGNAL(clicked(QAbstractButton*, bool)), bt, SLOT(activate()));
     connect(bt, SIGNAL(activated()), this, SLOT(actionActivated()));
 
     bt = new ActionButton(deletePB, "org.qt.policykit.examples.delete", this);
@@ -101,7 +102,7 @@ PkExample::PkExample(QMainWindow *parent)
     menuActions->addAction(qobject_cast<Action*>(bt));
     toolBar->addAction(qobject_cast<Action*>(bt));
     connect(bt, SIGNAL(triggered(bool)), this, SLOT(activateAction()));
-    connect(bt, SIGNAL(clicked(QAbstractButton*,bool)), bt, SLOT(activate()));
+    connect(bt, SIGNAL(clicked(QAbstractButton*, bool)), bt, SLOT(activate()));
     connect(bt, SIGNAL(activated()), this, SLOT(actionActivated()));
 
     bt = new ActionButton(bleedPB, "org.qt.policykit.examples.bleed", this);
@@ -110,7 +111,7 @@ PkExample::PkExample(QMainWindow *parent)
     menuActions->addAction(qobject_cast<Action*>(bt));
     toolBar->addAction(qobject_cast<Action*>(bt));
     connect(bt, SIGNAL(triggered(bool)), this, SLOT(activateAction()));
-    connect(bt, SIGNAL(clicked(QAbstractButton*,bool)), bt, SLOT(activate()));
+    connect(bt, SIGNAL(clicked(QAbstractButton*, bool)), bt, SLOT(activate()));
     connect(bt, SIGNAL(activated()), this, SLOT(actionActivated()));
 
     bt = new ActionButtons(QList<QAbstractButton*>() << listenPB << listenCB,
@@ -197,16 +198,16 @@ void PkExample::actionActivated()
 
         QDBusMessage message;
         message = QDBusMessage::createMethodCall("org.qt.policykit.examples",
-                                                 "/",
-                                                 "org.qt.policykit.examples",
-                                                 QLatin1String("play"));
+                  "/",
+                  "org.qt.policykit.examples",
+                  QLatin1String("play"));
         QList<QVariant> argumentList;
         argumentList << qVariantFromValue(QString("Daniel Nicoletti"));
         message.setArguments(argumentList);
         // notice the systemBus here..
         QDBusMessage reply = QDBusConnection::systemBus().call(message);
         if (reply.type() == QDBusMessage::ReplyMessage
-            && reply.arguments().size() == 1) {
+                && reply.arguments().size() == 1) {
             // the reply can be anything, here we receive a string
             qDebug() << reply.arguments().first().toString();
         } else if (reply.type() == QDBusMessage::MethodCallMessage) {
@@ -228,9 +229,9 @@ void PkExample::actionActivated()
 
     // note how we pass true to revokeIfOneShot - this is because we're
     // pretending to be the mechanism
-    PolKitResult result;
+    Auth::Result result;
     result = Auth::isCallerAuthorized(action->actionId(), static_cast<uint>(QCoreApplication::applicationPid()), true);
-    if (result == POLKIT_RESULT_YES) {
+    if (result == Auth::Yes) {
         // in the helper you will do the action
         qDebug() << "caller is authorized to do:" << action->actionId();
     } else {
